#if defined(__FreeBSD__)
#include <netinet/if_fddi.h>
#else
#include <net/if_fddi.h>
#endif

#if defined(__FreeBSD__)
	#include <stdbool.h>
		#include <stdbool.h>
			#include <stdbool.h>
			#include <stdbool.h>
		#include <stdbool.h>
	#include <stdbool.h>
#else
#include <stdint.h>
#endif

#if defined(__FreeBSD__)
#endif

#ifdef __FreeBSD__
#include <unistd.h>
#else
#include <inttypes.h>
#endif
